!-------------------------------------------------------------------------------

!                      Code_Saturne version 4.0.3-patch
!                      --------------------------
! This file is part of Code_Saturne, a general-purpose CFD tool.
!
! Copyright (C) 1998-2015 EDF S.A.
!
! This program is free software; you can redistribute it and/or modify it under
! the terms of the GNU General Public License as published by the Free Software
! Foundation; either version 2 of the License, or (at your option) any later
! version.
!
! This program is distributed in the hope that it will be useful, but WITHOUT
! ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
! FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
! details.
!
! You should have received a copy of the GNU General Public License along with
! this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
! Street, Fifth Floor, Boston, MA 02110-1301, USA.

!-------------------------------------------------------------------------------

!===============================================================================
! Purpose:
! -------

! \file cs_user_extra_operations-global_efforts.f90
! This is an example of cs_user_extra_operations.f90 which
! performs global efforts

!-------------------------------------------------------------------------------

!-------------------------------------------------------------------------------
! Arguments
!______________________________________________________________________________.
!  mode           name          role                                           !
!______________________________________________________________________________!
!> \param[in]     nvar          total number of variables
!> \param[in]     nscal         total number of scalars
!> \param[in]     dt            time step (per cell)
!_______________________________________________________________________________

subroutine cs_f_user_extra_operations &
 ( nvar   , nscal  ,                                              &
   dt     )

!===============================================================================

!===============================================================================
! Module files
!===============================================================================

use paramx
use dimens, only: ndimfb
use pointe
use numvar
use optcal
use cstphy
use cstnum
use entsor
use lagpar
use lagran
use lagdim
use parall
use period
use ppppar
use ppthch
use ppincl
use mesh
use field
use field_operator
use turbomachinery
use setup
!===============================================================================

implicit none

! Arguments

integer          nvar   , nscal

double precision dt(ncelet)

! Local variables

!< [loc_var_dec]
integer          ifac, iel
integer          ii
integer          ilelt  , nlelt

double precision xfor(3), xcof(3), torque, tcof, cyl_area
double precision, dimension(:,:), pointer :: for_br

integer, allocatable, dimension(:) :: lstelt

double precision, dimension(:), pointer :: cvar_scal, cvara_scal
!< [loc_var_dec]

!===============================================================================

!===============================================================================
! Initialization
!===============================================================================

if (ineedf.eq.1) call field_get_val_v(iforbr, for_br)

! Allocate a temporary array for cells or interior/boundary faces selection
allocate(lstelt(max(ncel,nfac,nfabor)))

call field_get_val_s(ivarfl(ipr), cvar_scal)
call field_get_val_prev_s(ivarfl(ipr), cvara_scal)


!===============================================================================
! User operations
!===============================================================================

! INSERT_MAIN_CODE_HERE

!file_drag_lift = impusr(1)
!file_ref_pres  = impusr(2)
! ----------------------------------------------
! The test below allows checking that the following example compiles
! while disabling it by default.
! ----------------------------------------------
! If efforts have been calculated correctly:
if (ineedf.eq.1) then
  do ii = 1, ndim
    xfor(ii) = 0.d0
    torque   = 0.d0
    xcof(ii) = 0.d0
    tcof     = 0.d0
  enddo
  call getfbr('wall', nlelt, lstelt)
  !==========
  do ilelt = 1, nlelt
    ifac = lstelt(ilelt)
    do ii = 1, ndim
      xfor(ii) = xfor(ii) + for_br(ii, ifac)
    enddo
    torque = xfor(2)*cdgfbo(1,ifac) - xfor(1)*cdgfbo(2,ifac)
  enddo
  if (irangp.ge.0) then
    call parrsm(ndim,xfor)
    call parsom(torque)
  endif
  cyl_area = depth*dia
  do ii=1,ndim
     xcof(ii) = xfor(ii) /(0.5d0*rho_ref*vel_ref**2*cyl_area)
  enddo
  tcof = torque/(0.5d0*rho_ref*vel_ref**2*cyl_area*radius)
  !open(file='drag_lift.dat',unit=file_drag_lift,access='append')
  if (ntcabs.eq.ntpabs+1) then
     write(nfecra,*) '#File with the time hystory for the lift and drag'
     write(nfecra,*) '#R    ', radius
     write(nfecra,*) '#Uinf ', vel_ref
     write(nfecra,*) '#rho  ', rho_ref
     write(nfecra,*) '#Front area  ', cyl_area
     write(nfecra,*) '#Structure of the results:'
     write(nfecra,*) '#Col 1: Time'
     write(nfecra,*) '#Col 2-3: Force in x and y'
     write(nfecra,*) '#Col 4: Torque'
     write(nfecra,*) '#Col 5: Cd'
     write(nfecra,*) '#Col 6: Cl'
     write(nfecra,*) '#Col 7: Ct'
  endif
  write(nfecra,1001)ttcabs,xfor(1),xfor(2),torque,xcof(1),xcof(2),tcof
  !close(unit=file_drag_lift)
endif

do iel = 1, ncel
   if (iel.eq.101) then
     write(nfecra,*) 'field pressure current', cvar_scal(iel), ' Previous', cvara_scal(iel)
   endif
enddo  

!if((ntcabs.eq.ntmabs).and.(nbmomt.gt.0)) then
!  ! reference pressure
!  iel1   = -999
!  irang1 = -999
!  imom   = 1 !average pressure 
!  ! position
!  xyz(1)=-10.0d0
!  xyz(2)= 0.0d0
!  xyz(3)= depth/2.d0
!  call findpt(ncelet, ncel, xyzcen, xyz(1), xyz(2), xyz(3), iel, irangv)
!  !==========
!  
!  if ((iel.ne.iel1).or.(irangv.ne.irang1)) then
!       iel1   = iel
!       irang1 = irangv
!       imom   = 1
!       ipcmom = ipproc(icmome(imom))
!       ! Set temporary variables xu, xv, ... for the process containing
!       ! the point and then send it to other processes.
!       if (irangp.eq.irangv) then
!         if(idtmom(imom).gt.0) then
!            idtcm = ipproc(icdtmo(idtmom(imom)))
!            xmomt = propce(iel,ipcmom)/            &
!                       max(propce(iel,idtcm),epzero)
!         elseif(idtmom(imom).lt.0) then
!            idtcm = -idtmom(imom)
!            xmomt = propce(iel,ipcmom)/            &
!                  max(dtcmom(idtcm),epzero)
!         endif
!         p_ref = xmomt
!       else
!         p_ref = 0.d0
!       endif
!  
!       ! Broadcast to other ranks in parallel
!       if (irangp.ge.0) then
!          iun = 1
!          call parbcr(irangv, iun, p_ref)
!       endif
!  endif
!  if(irangp.le.0) then
!     open(unit=file_ref_pres,file='User_ref_data.dat',form='formatted',status='unknown')
!     write(file_ref_pres,*) '# This file reports the references data for the case'
!     write(file_ref_pres,3001) uref
!     write(file_ref_pres,3002) t0
!     write(file_ref_pres,3003) twall
!     write(file_ref_pres,3005) p_ref
!     write(file_ref_pres,3006) ro0 
!     write(file_ref_pres,3007) viscl0
!     close(file_ref_pres)
!  endif
!
!
!endif

! Deallocate the temporary array
deallocate(lstelt)
1001 format('Coefficients ',7(e18.9,1x))
2001 format('#Ref pressure ',e18.8)

!     FORMATS
!3001 format('#Inlet velocity    ',e18.8)
!3002 format('#Inlet temperature ',e18.8)
!3003 format('#Wall temperature  ',e18.8)
!3005 format('#Ref pressure      ',e18.8)
!3006 format('#Ref density       ',e18.8)
!3007 format('#Ref viscosity     ',e18.8)


return
end subroutine cs_f_user_extra_operations
