!-------------------------------------------------------------------------------

!                      Code_Saturne version 4.0.3-patch
!                      --------------------------
! This file is part of Code_Saturne, a general-purpose CFD tool.
!
! Copyright (C) 1998-2015 EDF S.A.
!
! This program is free software; you can redistribute it and/or modify it under
! the terms of the GNU General Public License as published by the Free Software
! Foundation; either version 2 of the License, or (at your option) any later
! version.
!
! This program is distributed in the hope that it will be useful, but WITHOUT
! ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
! FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
! details.
!
! You should have received a copy of the GNU General Public License along with
! this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
! Street, Fifth Floor, Boston, MA 02110-1301, USA.

!-------------------------------------------------------------------------------

!===============================================================================
! Purpose:
! -------

!> \file cs_user_modules.f90
!>
!> \brief User-defined module: it allows to create any user array.
!>
!> This file is compiled before all other user Fortran files.
!> To ensure this, it must not be renamed.
!>
!> The user may define an arbitrary number of modules here, even though
!> only one is defined in the example.
!
!> \cond DOXYGEN_SHOULD_SKIP_THIS

!-------------------------------------------------------------------------------

! The user may define an arbitrary number of modules here, even though
! only one is defined in the example.

!-------------------------------------------------------------------------------
module setup

integer,parameter::imstart=1500
double precision angle, piu
parameter (piu=16.d0*atan(1.d0/5.d0)-4.d0*atan(1.d0/2.39d2))       
double precision,parameter::re  = 1.5d2                     
double precision,parameter::ma  = 0.1d0           
double precision,parameter::alpha_rot  = 0.D0                          
double precision,parameter::dia = 1.d0  
double precision,parameter::depth  = 1.0d0
double precision,parameter::radius = dia/2.d0
double precision,parameter::turbint= 0.0034d0
double precision,parameter::rho_ref= 1.205d0
double precision,parameter::cp_ref = 1005.d0
double precision,parameter::MM_ref = 0.0289645d0    !8.31446d0 !=> gamma ~ 1 R*=1 (This is to avoid negative temperature )0.0289645d0
double precision,parameter::T_ref =  3.d2
double precision,parameter::Gamma_ref = 1.d0+8.31446d0/(MM_ref*cp_ref-8.31446d0) 
double precision,parameter::vel_ref= ma*sqrt(Gamma_ref*(8.31446d0/MM_ref)*T_ref)
double precision,parameter::viscosity_mu=rho_ref*vel_ref*dia/re
!double precision,parameter::T_ref = vel_ref**2/(ma**2*1.4d0*2.87d2)
double precision,parameter::omega_ref  = alpha_rot*vel_ref / radius
! variables for the average in space
!integer         ,allocatable::cell_cellref(:)
!double precision,allocatable::ave_mom_xy(:,:)


end module setup
